pub struct EventBus { /* private fields */ }Expand description
Routes proxy events to multiple sinks via a bounded async channel.
The proxy hot path calls emit() which does a non-blocking channel send.
A background tokio task reads from the channel and fans out to all sinks.
Implementations