pub fn parse_body(body: &[u8]) -> Option<ParsedBody>Expand description
Parse a POST body as JSON-RPC 2.0 — single message or batch.
Returns None if the body is not valid JSON-RPC 2.0.
pub fn parse_body(body: &[u8]) -> Option<ParsedBody>Parse a POST body as JSON-RPC 2.0 — single message or batch.
Returns None if the body is not valid JSON-RPC 2.0.