pub struct ProxyState {
pub name: String,
pub mcp_upstream: String,
pub upstream: UpstreamClient,
pub max_request_body: usize,
pub max_response_body: usize,
pub rewrite_config: Arc<RwLock<RewriteConfig>>,
pub widget_source: Option<WidgetSource>,
pub sessions: MemorySessionStore,
pub schema_manager: Arc<SchemaManager<MemorySchemaStore>>,
pub health: SharedProxyHealth,
pub event_bus: EventBus,
}Expand description
Everything one running proxy needs to serve a request end-to-end.
Fields
name: StringProxy name used to tag events and look up per-proxy resources.
mcp_upstream: Stringupstream: UpstreamClientmax_request_body: usizemax_response_body: usizerewrite_config: Arc<RwLock<RewriteConfig>>widget_source: Option<WidgetSource>sessions: MemorySessionStoreschema_manager: Arc<SchemaManager<MemorySchemaStore>>health: SharedProxyHealthevent_bus: EventBusAuto Trait Implementations
impl Freeze for ProxyState
impl !RefUnwindSafe for ProxyState
impl Send for ProxyState
impl Sync for ProxyState
impl Unpin for ProxyState
impl UnsafeUnpin for ProxyState
impl !UnwindSafe for ProxyState