pub fn lock_state(state: &SharedProxyState) -> MutexGuard<'_, ProxyState>Expand description
Lock the shared state, recovering from poison if a thread panicked.
Prefer this over .lock().unwrap() — it never panics.
pub fn lock_state(state: &SharedProxyState) -> MutexGuard<'_, ProxyState>Lock the shared state, recovering from poison if a thread panicked.
Prefer this over .lock().unwrap() — it never panics.